summaryrefslogtreecommitdiffstats
path: root/source/core
diff options
context:
space:
mode:
Diffstat (limited to 'source/core')
-rw-r--r--source/core/slang-command-options-writer.cpp6
1 files changed, 4 insertions, 2 deletions
diff --git a/source/core/slang-command-options-writer.cpp b/source/core/slang-command-options-writer.cpp
index ecb5fa698..8cfade71e 100644
--- a/source/core/slang-command-options-writer.cpp
+++ b/source/core/slang-command-options-writer.cpp
@@ -504,8 +504,10 @@ void TextCommandOptionsWriter::appendDescriptionImpl()
{
const auto& category = categories[categoryIndex];
- // Omit the value categories and the "Internal" category for text output
- if (category.kind != CategoryKind::Value && category.name != toSlice("Internal"))
+ // Omit the value categories as well as the "Internal" and "Repro" categories from the text
+ // output
+ if (category.kind != CategoryKind::Value && category.name != toSlice("Internal") &&
+ category.name != toSlice("Repro"))
{
_appendDescriptionForCategory(categoryIndex);
}